==> qcs-api-client-0.4.3.tar.gz: qcs-api-client-0.4.3/qcs_api_client/operations/sync/__init__.py <==
from qcs_api_client.api.authentication.auth_email_password_reset_token import sync as auth_email_password_reset_token
from qcs_api_client.api.authentication.auth_get_user import sync as auth_get_user
from qcs_api_client.api.authentication.auth_reset_password import sync as auth_reset_password
from qcs_api_client.api.authentication.auth_reset_password_with_token import sync as auth_reset_password_with_token
from qcs_api_client.api.client_applications.check_client_application import sync as check_client_application
from qcs_api_client.api.client_applications.list_client_applications import sync as list_client_applications
from qcs_api_client.api.default.get_health import sync as get_health
from qcs_api_client.api.default.health_check import sync as health_check
from qcs_api_client.api.endpoints.get_default_endpoint import sync as get_default_endpoint
from qcs_api_client.api.endpoints.get_endpoint import sync as get_endpoint
from qcs_api_client.api.endpoints.list_endpoints import sync as list_endpoints
from qcs_api_client.api.engagements.create_engagement import sync as create_engagement
from qcs_api_client.api.quantum_processors.get_instruction_set_architecture import (
    sync as get_instruction_set_architecture,
)
from qcs_api_client.api.quantum_processors.get_quantum_processor import sync as get_quantum_processor
from qcs_api_client.api.quantum_processors.list_quantum_processors import sync as list_quantum_processors
from qcs_api_client.api.reservations.create_reservation import sync as create_reservation
from qcs_api_client.api.reservations.delete_reservation import sync as delete_reservation
from qcs_api_client.api.reservations.find_available_reservations import sync as find_available_reservations
from qcs_api_client.api.reservations.list_reservations import sync as list_reservations
from qcs_api_client.api.translation.get_quilt_calibrations import sync as get_quilt_calibrations
from qcs_api_client.api.translation.translate_native_quil_to_encrypted_binary import (
    sync as translate_native_quil_to_encrypted_binary,
)

==> qcs-api-client-0.6.0.tar.gz: qcs-api-client-0.6.0/qcs_api_client/operations/sync/__init__.py <==
from qcs_api_client.api.authentication.auth_email_password_reset_token import sync as auth_email_password_reset_token
from qcs_api_client.api.authentication.auth_get_user import sync as auth_get_user
from qcs_api_client.api.authentication.auth_reset_password import sync as auth_reset_password
from qcs_api_client.api.authentication.auth_reset_password_with_token import sync as auth_reset_password_with_token
from qcs_api_client.api.client_applications.check_client_application import sync as check_client_application
from qcs_api_client.api.client_applications.get_client_application import sync as get_client_application
from qcs_api_client.api.client_applications.list_client_applications import sync as list_client_applications
from qcs_api_client.api.default.get_health import sync as get_health
from qcs_api_client.api.default.health_check import sync as health_check
from qcs_api_client.api.endpoints.create_endpoint import sync as create_endpoint
from qcs_api_client.api.endpoints.delete_endpoint import sync as delete_endpoint
from qcs_api_client.api.endpoints.get_default_endpoint import sync as get_default_endpoint
from qcs_api_client.api.endpoints.get_endpoint import sync as get_endpoint
from qcs_api_client.api.endpoints.list_endpoints import sync as list_endpoints
from qcs_api_client.api.engagements.create_engagement import sync as create_engagement
from qcs_api_client.api.quantum_processors.get_instruction_set_architecture import (
    sync as get_instruction_set_architecture,
)
from qcs_api_client.api.quantum_processors.get_quantum_processor import sync as get_quantum_processor
from qcs_api_client.api.quantum_processors.list_quantum_processors import sync as list_quantum_processors
from qcs_api_client.api.reservations.create_reservation import sync as create_reservation
from qcs_api_client.api.reservations.delete_reservation import sync as delete_reservation
from qcs_api_client.api.reservations.find_available_reservations import sync as find_available_reservations
from qcs_api_client.api.reservations.list_reservations import sync as list_reservations
from qcs_api_client.api.translation.get_quilt_calibrations import sync as get_quilt_calibrations
from qcs_api_client.api.translation.translate_native_quil_to_encrypted_binary import (
    sync as translate_native_quil_to_encrypted_binary,
)
